@@ -1,7 +1,14 @@
 `twsConnect` <-
 function (clientId=1, host='localhost', port = 7496, verbose=TRUE,
-          timeout=10)
+          timeout=5, filename=NULL)
  {
+   if(is.null(getOption('digits.secs'))) 
+     options(digits.secs=6)
+
+   if(is.character(clientId))
+     filename <- clientId
+
+   if(is.null(filename)) {
      start.time <- Sys.time()
      s <- socketConnection(host = host, port = port,
                            open='ab', blocking=TRUE)
@@ -11,14 +18,16 @@ function (clientId=1, host='localhost', port = 7496, verbose=TRUE,
        stop(paste("couldn't connect to TWS on port",port))
      }
 
-     writeBin("33", s)
+     CLIENT_VERSION <- "37"
+
+     writeBin(CLIENT_VERSION, s)
      writeBin(as.character(clientId), s)
 
      waiting <- TRUE
      while(waiting) {
        curMsg <- readBin(s, character(), 1)
        if(length(curMsg) > 0) {
-         if(curMsg %in% c('39','40')) {
+         if(curMsg %in% as.character(39:43)) {
            SERVER_VERSION <- curMsg
            CONNECTION_TIME <- readBin(s,character(),1)
          }
@@ -41,44 +50,26 @@ function (clientId=1, host='localhost', port = 7496, verbose=TRUE,
                     server.version=SERVER_VERSION,
                     connected.at=CONNECTION_TIME), 
                     class = "twsConnection")
- }
-`twsConnect2` <-
-function (clientId=1, host='localhost', port = 7496, verbose=TRUE,
-          timeout=10)
- {
-     start.time <- Sys.time()
-     s <- socketConnection(host = host, port = port, open='ab')
+  } else { 
+    #file is defined - not a real connection
+    fh <- file(filename,open='r')
+    dat <- scan(fh, what=character(), quiet=TRUE)
+    close(fh)
 
-     if(!isOpen(s)) { 
-       close(s)
-       stop(paste("couldn't connect to TWS on port",port))
-     }
+    tmp <- tempfile()
+    fh <- file(tmp, open='ab')
 
-     writeBin("37", s)
-     waiting <- TRUE
-     while(waiting) {
-       response <- readBin(s,character(),1)
-       if(length(response) > 0 && response %in% c('39','40')) {
-         SERVER_VERSION <- response
-         while(waiting) {
-           response <- readBin(s,character(),1)
-           if(length(response) > 0) {
-             CONNECTION_TIME <- response
-             waiting <- FALSE
-           }
-         }
-       }
-       if(Sys.time()-start.time > timeout) {
-         close(s)
-         stop('tws connection timed-out')
-       }
-     }
+    writeBin(c(as.character(length(dat)),dat), fh)
+    #for(i in dat) writeBin(i, fh)
 
-     writeBin(as.character(clientId), s)
+    close(fh)
+    s <- file(tmp, open='rb')
 
-     structure(list(s,
-                    clientId=clientId,port=port,
-                    server.version=SERVER_VERSION,
-                    connected.at=CONNECTION_TIME), 
-                    class = "twsConnection")
- }
+    structure(list(s,
+                   clientId=NULL,port=NULL,
+                   server.version=NULL,
+                   connected.at=filename), 
+                   class = c("twsPlayback","twsConnection"))
+
+  }
+}
