@@ -1,8 +1,10 @@
 `twsEquity` <-
-function(symbol,exch,primary,strike='0.0',
+function(symbol,exch="SMART",primary="",strike='0.0',
          currency='USD',right='',local='',multiplier='',include_expired='0')
 {
   twsContract(symbol,'STK',exch,primary,expiry='',strike,
               currency,right,local,multiplier,NULL,NULL,include_expired)
 }
 
+
+`twsSTK` <- twsEquity
