@@ -23,20 +23,22 @@ structure(list(REQ_MKT_DATA = "1", CANCEL_MKT_DATA = "2", PLACE_ORDER = "3",
 
 `.twsIncomingMSG` <-
 structure(list(TICK_PRICE = "1", TICK_SIZE = "2", 
-    ORDER_SIZE = "3", ERR_MSG = "4", OPEN_ORDER = "5", ACCT_VALUE = "6", 
+    ORDER_STATUS = "3", ERR_MSG = "4", OPEN_ORDER = "5", ACCT_VALUE = "6", 
     PORTFOLIO_VALUE = "7", ACCT_UPDATE_TIME = "8", NEXT_VALID_ID = "9", 
     CONTRACT_DATA = "10", EXECUTION_DATA = "11", MARKET_DEPTH = "12", 
     MARKET_DEPTH_L2 = "13", NEWS_BULLETINS = "14", MANAGED_ACCTS = "15", 
     RECEIVE_FA = "16", HISTORICAL_DATA = "17", BOND_CONTRACT_DATA = "18", 
     SCANNER_PARAMETERS = "19", SCANNER_DATA = "20", TICK_OPTION_COMPUTATION = "21", 
     TICK_GENERIC = "45", TICK_STRING = "46", TICK_EFP = "47", 
-    CURRENT_TIME = "49", REAL_TIME_BARS = "50"), .Names = c("TICK_PRICE", 
-"TICK_SIZE", "ORDER_SIZE", "ERR_MSG", "OPEN_ORDER", "ACCT_VALUE", 
+    CURRENT_TIME = "49", REAL_TIME_BARS = "50", FUNDAMENTAL_DATA = "51",
+    CONTRACT_DATA_END = "52"), .Names = c("TICK_PRICE", 
+"TICK_SIZE", "ORDER_STATUS", "ERR_MSG", "OPEN_ORDER", "ACCT_VALUE", 
 "PORTFOLIO_VALUE", "ACCT_UPDATE_TIME", "NEXT_VALID_ID", "CONTRACT_DATA", 
 "EXECUTION_DATA", "MARKET_DEPTH", "MARKET_DEPTH_L2", "NEWS_BULLETINS", 
 "MANAGED_ACCTS", "RECEIVE_FA", "HISTORICAL_DATA", "BOND_CONTRACT_DATA", 
 "SCANNER_PARAMETERS", "SCANNER_DATA", "TICK_OPTION_COMPUTATION", 
-"TICK_GENERIC", "TICK_STRING", "TICK_EFP", "CURRENT_TIME", "REAL_TIME_BARS"
+"TICK_GENERIC", "TICK_STRING", "TICK_EFP", "CURRENT_TIME", "REAL_TIME_BARS",
+"FUNDAMENTAL_DATA","CONTRACT_DATA_END"
 ))
 
 `.twsERR` <-
